@@ -386,11 +386,13 @@ class FederatedPipelineBase(AMLPipelineHelper):
 
         @lru_cache(maxsize=None)
         @dsl.pipeline(display_name=self.create_subgraph_name())
-        def _subpipeline_function(use_secure_aggregation: bool, **kwargs):
+        def _subpipeline_function(**kwargs):
             cool_name = self.create_base_name()
             midprocess_input = {}
             # if not using secure aggregation
-            if not use_secure_aggregation:
+            if (
+                not self.config.federated_config.use_secure_aggregation
+            ):  # use_secure_aggregation:
                 i = 1
                 for silo_name, silo in self.config.federated_config.silos.items():
                     train_output = self._train_in_silo_once(
@@ -576,13 +578,10 @@ class FederatedPipelineBase(AMLPipelineHelper):
                         for output_name in prev_output.keys()
                     }
                     subpipeline = _subpipeline_function(
-                        use_secure_aggregation=self.config.federated_config.use_secure_aggregation,
                         **prev_output,
                     )
                 else:
-                    subpipeline = _subpipeline_function(
-                        use_secure_aggregation=self.config.federated_config.use_secure_aggregation
-                    )
+                    subpipeline = _subpipeline_function()
                 subpipeline.node_name = self.create_iteration_name()
                 prev_output = subpipeline.outputs
 
