@@ -16,7 +16,7 @@ import uuid
 import shutil
 import yaml
 import jsonpath_ng
-from typing import Callable, Optional
+from typing import Callable, Optional, Set
 from toposort import toposort_flatten
 import datetime
 from dataclasses import dataclass
@@ -26,7 +26,7 @@ try:
     import hydra
     from hydra.core.config_store import ConfigStore
     from hydra.core.hydra_config import HydraConfig
-    from omegaconf import DictConfig, OmegaConf, open_dict
+    from omegaconf import DictConfig, OmegaConf, open_dict, MISSING
     from flatten_dict import flatten
 
     import azureml
@@ -52,7 +52,7 @@ from shrike.pipeline.pipeline_config import (
     HDI_DEFAULT_CONF,
 )
 from shrike.pipeline.telemetry_utils import TelemetryLogger
-from shrike._core import is_eyesoff_helper, POLYMER_FEED
+from shrike._core import is_eyesoff_helper, POLYMER_FEED, O365_FEED
 
 
 log = logging.getLogger(__name__)
@@ -1579,7 +1579,9 @@ class AMLPipelineHelper:
         old_env_file_path = None
         if env_yaml_override_is_needed:
             spec_dirname = os.path.dirname(spec_path)
-            log.info(f"Will remove {POLYMER_FEED} from environment.conda.")
+            log.info(
+                f"Will remove {POLYMER_FEED} and {O365_FEED} from environment.conda."
+            )
             try:
                 if spec["type"] == "spark":
                     conda_dependencies_file = spec["environment"]["conda_file"]
@@ -1593,8 +1595,8 @@ class AMLPipelineHelper:
                     new_file,
                     new_env_file_path,
                     old_env_file_path,
-                ) = self._remove_polymer_pkg_idx_if_exists_and_save_new(
-                    spec_dirname, conda_dependencies_file, POLYMER_FEED
+                ) = self._remove_python_package_feed_if_exists_and_save_new(
+                    spec_dirname, conda_dependencies_file, [POLYMER_FEED, O365_FEED]
                 )
                 if found_index_url:
                     if spec["type"] == "spark":
@@ -1619,8 +1621,10 @@ class AMLPipelineHelper:
                         pip_dependencies = dependency["pip"]
                         if POLYMER_FEED in pip_dependencies:
                             pip_dependencies.remove(POLYMER_FEED)
-                            dependency["pip"] = pip_dependencies
-                            conda_dependencies[idx] = dependency
+                        if O365_FEED in pip_dependencies:
+                            pip_dependencies.remove(O365_FEED)
+                        dependency["pip"] = pip_dependencies
+                        conda_dependencies[idx] = dependency
                 if spec["type"] == "spark":
                     spec["conda_dependencies"]["dependencies"] = conda_dependencies
                 else:
@@ -1640,8 +1644,8 @@ class AMLPipelineHelper:
                     new_file,
                     new_env_file_path,
                     old_env_file_path,
-                ) = self._remove_polymer_pkg_idx_if_exists_and_save_new(
-                    spec_dirname, pip_requirements_file, POLYMER_FEED
+                ) = self._remove_python_package_feed_if_exists_and_save_new(
+                    spec_dirname, pip_requirements_file, [POLYMER_FEED, O365_FEED]
                 )
                 if found_index_url:
                     spec["environment"]["conda"]["pip_requirements_file"] = new_file
@@ -1653,8 +1657,8 @@ class AMLPipelineHelper:
             yaml.safe_dump(spec, file)
         return old_spec_path, old_env_file_path, new_env_file_path
 
-    def _remove_polymer_pkg_idx_if_exists_and_save_new(
-        self, spec_dirname, file, polymer_pkg_idx
+    def _remove_python_package_feed_if_exists_and_save_new(
+        self, spec_dirname, file, package_feeds
     ):
         found_index_url = False
         new_file = ""
@@ -1663,9 +1667,11 @@ class AMLPipelineHelper:
         with open(os.path.join(spec_dirname, file), "r") as f:
             lines = f.readlines()
         for line in lines:
-            if polymer_pkg_idx in line:
-                found_index_url = True
-                lines.remove(line)
+            for feed in package_feeds:
+                if feed in line:
+                    found_index_url = True
+                    lines.remove(line)
+                    break
         if found_index_url:
             file_name, file_ext = os.path.splitext(file)
             new_file = file_name + "_" + self.config.aml.tenant + file_ext
@@ -1721,10 +1727,15 @@ class AMLPipelineHelper:
                 log.error(f"An error occurred, recovery is not successful: {e}")
 
     def _update_dc_configs(self, pipeline):
-        hdi_compute = self.config.compute.hdi_dc_target
-        synapse_compute = self.config.compute.synapse_dc_target
-        if not hdi_compute and not synapse_compute:
-            log.info("This pipeline doesn't involve HDI DC or Synapse DC.")
+        # workaround for missing "throw_on_missing" in currently used omegaconf
+        compute_config_as_dict = yaml.safe_load(OmegaConf.to_yaml(self.config.compute))
+        dc_targets: Set[str] = {
+            target
+            for key, target in compute_config_as_dict.items()
+            if key.endswith("_dc_target") and target and target != str(MISSING)
+        }
+        if not dc_targets:
+            log.info("The compute config does not involve any DC targets.")
             return pipeline
         nodes = pipeline._expand_pipeline_nodes()
         graph = defaultdict(list)
@@ -1754,16 +1765,15 @@ class AMLPipelineHelper:
             if id not in node_mapping:
                 continue
             node = node_mapping[id]
-            if not isinstance(node.runsettings.target, str):
-                log.warn(
-                    f"The compute target of node {node.name} is a PipelineParameter. Shrike will not update even if this or the upstream steps use HDI DC or Synapse DC. Please update manually."
-                )
-            elif node.type != "ScopeComponent" and (
-                (hdi_compute and node.runsettings.target == hdi_compute)
-                or (synapse_compute and node.runsettings.target == synapse_compute)
-            ):
-                use_dc[id] = True
-                continue
+            # scope component doesn't configure compute target
+            if node.type != "ScopeComponent":
+                if not isinstance(node.runsettings.target, str):
+                    log.warn(
+                        f"The compute target of node {node.name} is a PipelineParameter. Shrike will not update even if this or the upstream steps use HDI DC or Synapse DC. Please update manually."
+                    )
+                elif node.runsettings.target in dc_targets:
+                    use_dc[id] = True
+                    continue
             for parent in graph[id]:
                 if use_dc[parent]:
                     use_dc[id] = True
